==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
            }
            if (a.j(WebFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOperation");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Name", "String");
            a.item("IsUnary", "Boolean");
            a.item("IconName", "String");
            a.item("Hidden", "Boolean");
        }
        static d(a) {
            WebFilteringOperationDescriptionMetadata.b(a);
            a.aa("WebFilteringOperation", () => new WebFilteringOperationDescription());
            a.z("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringOperationDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOperation");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Name", "String");
            a.item("IsUnary", "Boolean");
            a.item("IconName", "String");
            a.item("Hidden", "Boolean");
        }
        static d(a) {
            WebFilteringOperationDescriptionMetadata.b(a);
            a.ac("WebFilteringOperation", () => new WebFilteringOperationDescription());
            a.ab("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringOperationDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
})();
